//@line 4 "/builds/slave/tb-rel-c-beta-lx_rpk_7-0000000/l10n/nn-NO/calendar/lightning-l10n.js"

//@line 6 "/builds/slave/tb-rel-c-beta-lx_rpk_7-0000000/l10n/nn-NO/calendar/lightning-l10n.js"

//@line 9 "/builds/slave/tb-rel-c-beta-lx_rpk_7-0000000/l10n/nn-NO/calendar/lightning-l10n.js"
pref("calendar.week.start", 1);

//@line 12 "/builds/slave/tb-rel-c-beta-lx_rpk_7-0000000/l10n/nn-NO/calendar/lightning-l10n.js"
pref("calendar.week.d0sundaysoff", true);
pref("calendar.week.d1mondaysoff", false);
pref("calendar.week.d2tuesdaysoff", false);
pref("calendar.week.d3wednesdaysoff", false);
pref("calendar.week.d4thursdaysoff", false);
pref("calendar.week.d5fridaysoff", false);
pref("calendar.week.d6saturdaysoff", true);

pref("general.useragent.locale", "nn-NO");

//@line 23 "/builds/slave/tb-rel-c-beta-lx_rpk_7-0000000/l10n/nn-NO/calendar/lightning-l10n.js"
pref("calendar.categories.names", "Arbeid,Favorittar,Ferie,Fridagar,Fødselsdag,Gåver,Idear,Jubileum,Klientar,Konkurranse,Kunde,Leverandørar,Møte,Offentleg helgedag,Oppfølging,Personleg,Problem,Prosjekt,Reise,Status,Telefonsamtalar,Ymse");

